import { IGame } from './IGame';
import { GameSettings, GaSettings } from './types';
export declare abstract class GameBase implements IGame {
    private _step;
    private _actionStep;
    private _hasFinished;
    private readonly _gameSettings;
    private readonly _gaSettings;
    protected constructor();
    get step(): number;
    get actionStep(): number;
    get gameSettings(): GameSettings;
    get gaSettings(): GaSettings;
    private get stepLimit();
    get hasReached(): boolean;
    protected onFinished(): void;
    protected abstract getGameSettings(): GameSettings;
    protected abstract getGaSettings(): GaSettings;
    abstract clone(): IGame;
    action(index: number): void | never;
    protected abstract performAction(index: number): void;
    perceive(index: number): boolean | never;
    protected abstract performPerceive(index: number): boolean;
    actionExpression(index: number): string;
    perceiveExpression(index: number): string;
    protected getCorrectionItemFitness(): number;
    getFitness(): number;
    protected abstract performGetFitness(): number;
    private static getCanvas;
    draw(target: string | HTMLCanvasElement): void;
    protected preDrawPixels(_pixels: Uint8ClampedArray): void;
    protected getBackgroundColor(): string;
    protected getPixelColor(_x: number, _y: number): [number, ...number[]] | undefined;
    protected parseColors(colors: [number, ...number[]]): {
        red: number;
        green: number;
        blue: number;
        alpha: number;
    };
    protected performDrawPixels(pixels: Uint8ClampedArray): void;
    protected performDraw(_context: CanvasRenderingContext2D): void;
}
